/***************************************************************************'
'																			'
'	SCPI_Test.cpp : main project file.						04/22/2011		'
'																			'
'	C Demo Program	Microsoft Visual Studio 2008							'
'	Copyright 2011 ICS Electronics div Systems West, Inc.					'
'																			'
'   Example C Program using SCPI commands to talk with a 80x3				'
'			Note: code was tested using an 8063								'
'																			'
'	For more information SEE 80x3 Manual 3.6 for SCPI commands.				'
'																			'
'	Requirement:  This was built with National Instruments VISA and			'
'					must have VISA installed for this to build and run.		'
'***************************************************************************'
'																			'
'		The program starts with a write of an "*IDN?" and then performs a	'
'		read of the devices reply. This section of the code it to confirm	'
'		connectivity to your device. targetIP is the variable you may		'
'		want to change if your device if not communicating. Current			'
'		settings should work with ICS Electronics devices with default		'
'		configurations. After Confirming connectivity four SCPI commands	'
'		are sent to the device, command0-4 may be changed to suit your		'
'		needs.																'
'																			'
'		If returning a non-zero then an error occured otherwise a zero		'
'		will be returned.													'
'***************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <conio.h>
#include "visa.h"


#define WaitForKeystroke   {while (!_kbhit()) {}}

static char outputBuffer[VI_FIND_BUFLEN];
static ViSession defaultRM, instr;
static ViStatus status;
static ViUInt32 count;
static ViUInt16 portNo;




//TargetIP can be changed here to locate your own device.
//Current Example Works with ICS Electronics default settings.
static char targetIP[] = "TCPIP0::192.168.0.254::inst0::INSTR"; //

//SCPI commands used in VIWrite command.
//These can be changed to fit your needs

//Sets Port 4 Outputs to low polarity true
static char command0[] = "SOURce:DATA:PORT4:POLarity #h00";	
//Sets Port 4 Outputs to zero
static char command1[] = "SOURCE:DATA:PORT4 0";	
//Outputs a one on port 4 bit 1
static char command2[] = "ROUTe:CLOSe 4,1 ";				
//Sets Port 1 Inputs to High polarity true
static char command3[] = "SENSE:DATA:PORT1:POLARITY #HFF";	
//Reads Port 1
static char command4[] = "SENSE:DATA:PORT1?";				


int main(void)
{
char result[100];

    // First we will need to open the default resource manager. 
    status = viOpenDefaultRM (&defaultRM);
    if (status < VI_SUCCESS)
    {
		printf("Could not open a session to the VISA Resource Manager!\n");
		printf("Press any key to continue\n");
		WaitForKeystroke
		return(1);
    }  

    // Now we will open a session via TCP/IP 
    // TargetIP can be modified via static char listed above.
    status = viOpen (defaultRM, targetIP, 0, 0, &instr);
    if (status < VI_SUCCESS)
    {
		viClose(defaultRM);
		printf ("An error occurred opening the session to %s\n",targetIP);
		printf("Press any key to continue\n");
		WaitForKeystroke
		return(1);
    }
	
	//Sets Delay Time
    viSetAttribute (instr, VI_ATTR_TCPIP_NODELAY, 1);
   
	//Uses the viWrite command to write an "*idn?" message.
	//See viWrite command for more information.
	status = viWrite (instr, "*idn?\n", 6, &count);		 
	if (status < VI_SUCCESS)	
    {
        viClose(defaultRM);
		printf("viWrite *idn? failed with error code %x \n",status);
		printf("Press any key to continue\n");
		WaitForKeystroke
		return(1);;
    }

    //Reads reply and saves reply in result.
    status = viRead (instr, result, 100, &count); 
    if (status < VI_SUCCESS)	
    {
		viClose(defaultRM);
		printf("viRead failed with error code %x \n",status);
		WaitForKeystroke
		return(1);
    }
	//places end of string at the end of the IDN reply
    result[count] = '\0';	
	//prints reply message to "*IDN?"
    printf("The server response is:\n %s\n\n", result);
	
		
/*--------------------------------------------------*/
/*			//------SCPI Commands------//			*/
/*--------------------------------------------------*/
	printf("Press any key to start SCPI commands\n");
	WaitForKeystroke				
	// command0-4 are SCPI commands listed at the top.
	
	//Sets Port 4 Outputs to low polarity true
	status = viWrite (instr, command0, sizeof(command0), &count);				
	if (status < VI_SUCCESS)													
	{
		printf("viWrite command0 failed with error code %x \n",status);
		printf("Press any key to continue\n");
		WaitForKeystroke
	}

	//Sets Port 4 Outputs to zero
	status = viWrite (instr, command1, sizeof(command1), &count);		
	if (status < VI_SUCCESS)				//Error Checking
	{
		printf("viWrite command1 failed with error code %x \n",status);
		printf("Press any key to continue\n");
		WaitForKeystroke
	}

	//Outputs a one on port 4 bit 1
	status = viWrite (instr, command2, sizeof(command2), &count);	
	if (status < VI_SUCCESS)				//Error Checking
	{
		printf("viWrite command2 failed with error code %x \n",status);
		printf("Press any key to continue \n");
		WaitForKeystroke
	}
				
	//Sets Port 1 Inputs to High polarity true
	status = viWrite (instr, command3, sizeof(command3), &count);
	if (status < VI_SUCCESS)				//Error Checking
	{
		printf("viWrite command3 failed with error code %x \n",status);
		printf("Press any key to continue \n");
		WaitForKeystroke
	}
	
	//Reads Port 1 
	status = viWrite (instr, command4, sizeof(command4), &count);			
	if (status < VI_SUCCESS)				//Error Checking
	{
		printf("viWrite command4 failed with error code %x \n",status);
		printf("Press any key to continue \n");
		WaitForKeystroke
	}
	
	//Closes all resources
	status = viClose (instr);
	status = viClose (defaultRM);
    printf ("\nHit any key to exit.");
	WaitForKeystroke

    return 0;  
}
